/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/


#include <qpe/config.h>
#include <qpe/resource.h>
#include <qstring.h>
#include <qfile.h>
#include <qpopupmenu.h>
#include <qlist.h>
#include <qpoint.h>

#include "bookmark.h"
#include "settings.h"


Bookmark::Bookmark(const QString &name, const QString &dir)
{
    setName(name);
    setDirectory(dir);
}

void Bookmark::setName(const QString &name)
{
    Name = name;
}

void Bookmark::setDirectory(const QString &dir)
{
    Dir = dir;
}

QString Bookmark::name()
{
    return Name;
}

QString Bookmark::directory()
{
    return Dir;
}

bool Bookmark::isAvailable()
{
    return QFile::exists(Dir);
}

BookmarkMenu::BookmarkMenu(QWidget *parent, Settings *s)
            : QPopupMenu(parent)
{
    settings = s;
    load();
}

void BookmarkMenu::load()
{
    //reload all bookmarks
    QListIterator<Bookmark> it(*settings->bookmarks());
    clear();
    insertItem(Resource::loadPixmap("DocsIcon"), "Documents", 0);
    if(!it.isEmpty())
        insertSeparator();
    for( int id = 1; it.current(); ++it, id++)
    {
        insertItem((*it)->name(), id);
        //set the item available only if the directory exists
        setItemEnabled(id, (*it)->isAvailable());
    }
}

void BookmarkMenu::popupMenu(const QPoint& p)
{
    //popup the menu at position p
    Bookmark *bm;
    int id = exec(p);
    if(id==-1)
        return;
    else if(id == 0) //Documents
        emit documentsSelected();
    else
    {
        bm = settings->bookmarks()->at(id-1);
        emit bookmarkSelected(*bm);
    }
}

