/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/

#include <qpe/applnk.h>
#include <qlistview.h>
#include <qstring.h>
#include <qpalette.h>
#include <qpainter.h>

#include "imagelistview.h"
#include "imagereader.h"
#include "icons.h"

ImageListViewItem::ImageListViewItem(QListView *parent, DocLnk *d)
                 : QListViewItem(parent)
{
    doc = d;
    color = white;

    //load image dimension only for jpeg files
    //for all other image formats the thumbnail box set the size
    //to not load the image twice
    ImageReader imageReader;
    imageReader.load( doc->file(), TRUE );
    int width = imageReader.imageWidth();
    int height = imageReader.imageHeight();
    imageReader.reset();
    sizeString = QString("%1x%2").arg(width).arg(height);

    //image icon
    setPixmap(0, qembed_findPixmap("image") );
    setText(0, doc->name());
    setText(1, sizeString);
}

DocLnk *ImageListViewItem::docLnk()
{
    return doc;
}

bool ImageListViewItem::Color()
{
    return color;
}

void ImageListViewItem::paintCell( QPainter *p, const QColorGroup &cg,
                                   int column, int width, int align )
{
    setText(0, doc->name() );
    QColorGroup _cg = cg;

    //paints items white and blue
    ImageListViewItem *item = (ImageListViewItem*)itemAbove();
    if(!item) //it's the first item
        color = white;
    else
    {
        if( item->Color() == white )
        {
            _cg.setColor( QColorGroup::Base, QColor(201, 221, 226) );
            color = blue;
        }
        else
            color = white;
    }

    QListViewItem::paintCell(p, _cg, column, width, align);
}


ImageListView::ImageListView(QWidget *parent, const char *name=0)
             : QListView(parent, name)
{
    addColumn("Name");
    addColumn("Size");
    setColumnAlignment ( 1, AlignRight ); //align size column
}

ImageListViewItem *ImageListView::find(DocLnk *d)
{
    //find the item by doclnk
    QListViewItemIterator it(this);
    for( ; it.current(); ++it)
    {
        ImageListViewItem *item = (ImageListViewItem *)it.current();
        if( item->docLnk() == d )
           return item;
    }
    return 0;
}

void ImageListView::removeItem(DocLnk *d)
{
    takeItem(find(d));
}

void ImageListView::keyReleaseEvent(QKeyEvent *keyEvent)
{
    //show the image when space is pressed
    if(keyEvent->key() == Key_Space)
        emit clicked(currentItem());
}
