/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/


#ifndef _IMAGESHOW_H
#define _IMAGESHOW_H

#include <qdialog.h>
#include <qlist.h>
#include <qpixmap.h>
#include <qpopupmenu.h>
#include "imagereader.h"

class ImageWidget;
class QString;
class QImage;
class QScrollView;
class QPixmap;
class QPopupMenu;
class DocLnk;
class Settings;
class QComboBox;
class ImageReader;
class QSize;
class QLabel;
class QToolButton;


class ZoomPopup : public QPopupMenu
{
friend class ImageViewer;

    Q_OBJECT
public:
    ZoomPopup(ImageViewer *imageViewer);
    ~ZoomPopup() { };
    void setZoom(int z);
    void setZoomStatus(QString status);
    void enableZoomIn(bool);
    void enableZoomOut(bool);
    void enableZoomMax(bool);

private:
    QLabel *zoomLabel;
    QToolButton *zoomIn, *zoomOut, *zoomMax;
};

class ImageViewer : public QDialog
{
    Q_OBJECT
public:
    ImageViewer(QWidget *parent, Settings *s, const char* name=0);
    ~ImageViewer() { };

    void reset();
    void updateImage( QPixmap *pix );
    void showFullScreen(DocLnk *d);

public slots:
    void load( DocLnk *d );

protected:
    void closeEvent( QCloseEvent *e);
    void accept();
    void keyReleaseEvent( QKeyEvent *keyEvent);

private slots:
    void scaleToScreen();
    void zoomIn();
    void zoomOut();
    void zoomMax();
    void rotate90();
    void rotate180();
    void rotate270();
    void rotateBestFit();
    void brightUpImage();
    void brightDownImage();
    void showFullScreen();
    void showInfoDialog();

private:
    void zoom(int ratio);
    void rotate(int degree);
    void brightImage();
    void intensity(QImage *img, float percent);
    QSize rectSize();

    enum CHECKS {
        AUTO_BEST_FIT
    };

    enum INFO_FIELDS {
        NAME,
        FORMAT,
        LOCATION,
        FILE_SIZE,
        DIMENSION,
        COLORS
    };

    ImageReader imageReader;
    DocLnk *doc;
    QImage *image;
    QPixmap pm, bpix;
    ImageWidget *imageWid, *fullScreen;
    QLabel *statusLabel;
    QScrollView *scroll;
    QPopupMenu *rotatePopup;
    ZoomPopup *zoomPopup;
    Settings *settings;
    int brightness, rotateDegree; //current brightness and rotate value
    int imageWidth, imageHeight; //original image size
    int currentZoom;
    bool scaledToScreen;
    int max;  //max zoom
    QString imageInfo[6];
};


#endif

