/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/


#include <qpixmap.h>
#include <qpainter.h>

#include "imagewidget.h"


ImageWidget::ImageWidget(QWidget *parent, const char *name, WFlags f)
           : QWidget(parent, name, f)
{
    pixmap = 0;
    closing = FALSE;
    setBackgroundMode( NoBackground );
}

ImageWidget::~ImageWidget()
{
   // delete pixmap;
}

void ImageWidget::setPixmap( QPixmap *pm, bool res )
{
    pixmap = pm;
    // res says if the widget needs to be resized
    // TRUE in imageviewer, FALSE for fullscreen show (slideshow)
    if( res ) resize(pm->width(),pm->height());
}

void ImageWidget::paintEvent( QPaintEvent * )
{
    if(!pixmap || closing)
        return;

    if ( pixmap->size() != QSize( 0, 0 ) )
    {
       int x = (width()-pixmap->width())/2;
       int y = (height()-pixmap->height())/2;
       bitBlt( this, x, y, pixmap, 0, 0, pixmap->width(),
               pixmap->height(), CopyROP );
    }
    else
    {
        QPainter p(this);
        p.fillRect( rect(), QColor(0,0,0) );
    }
}

void ImageWidget::mouseReleaseEvent( QMouseEvent * )
{
    emit clicked();
}

void ImageWidget::keyReleaseEvent ( QKeyEvent *keyEvent )
{
    int key = keyEvent->key();

    if(key == Key_Escape)
    {
        emit CancelPressed();
        close();
    }
    else if(key == Key_Down || key == Key_Enter)
        emit OKPressed();

    keyEvent->accept();
}

void ImageWidget::closeEvent ( QCloseEvent * e )
{
    closing = TRUE;
    pixmap->resize(0,0);
    e->accept();
}
