/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/


#include <qpe/config.h>
#include <qlist.h>
#include <qstring.h>
#include "bookmark.h"
#include "settings.h"

Settings::Settings()
{
    bmList.setAutoDelete( TRUE );
}

void Settings::writeSettings()
{
    Config config("tximage");
    config.setGroup("Settings");
    config.writeEntry("slideDelay", slideDelay() );
    config.writeEntry("rotateinSlide", rotateInSlide() );
    config.writeEntry("view", view());
    config.writeEntry("rotateBestFit", rotateBestFit() );
    config.writeEntry("controlBarInSlide", controlBarInSlide() );
    config.writeEntry("imageFullScreen", showImageFullScreen() );
    config.writeEntry("saveThumbnails", saveThumbnail() );
    config.writeEntry("thumbFileSize", thumbFileSize() );
    config.writeEntry("showExtension", showFileExtension() );
    config.writeEntry("showDimension", showImageDimension() );
    config.setGroup("Bookmarks");
    QListIterator<Bookmark> it(bmList);
    config.writeEntry("numBookmarks", (int)bmList.count());
    for( int id=0; it.current() ; ++it, ++id )
    {
        Bookmark *bm = (Bookmark *)it.current();
        config.writeEntry( QString("name%1").arg(id), bm->name() );
        config.writeEntry( QString("dir%1").arg(id), bm->directory() );
    }
    qDebug("settings saved");
}

void Settings::readSettings()
{
    Config config("tximage");
    config.setGroup("Settings");
    setView( config.readNumEntry("view", 0) ); //default: thumbnailview
    setRotateBestFit( config.readBoolEntry("rotateBestFit", FALSE) );
    setControlBarInSlide( config.readBoolEntry("controlBarInSlide", TRUE) );
    setShowImageFullScreen( config.readBoolEntry("imageFullScreen", FALSE) );
    setSlideDelay( config.readNumEntry("slideDelay", 2) );
    setRotateInSlide( config.readBoolEntry("rotateInSlide", TRUE) );
    setSaveThumbnail( config.readBoolEntry("saveThumbnails", TRUE) );
    setThumbFileSize( config.readNumEntry("thumbFileSize", 30) );
    setShowFileExtension( config.readBoolEntry("showExtension", FALSE) );
    setShowImageDimension( config.readBoolEntry("showDimension", TRUE) );
    loadBookmarks();
}


void Settings::loadBookmarks()
{
    Config config("tximage");
    config.setGroup("Bookmarks");
    numBookmarks = config.readNumEntry("numBookmarks", 0);
    for(int id=0; id < numBookmarks ; id++)
    {
        Bookmark *bm = new Bookmark();
        QString name = config.readEntry(QString("name%1").arg(id));
        bm->setName( name );
        bm->setDirectory(config.readEntry(QString("dir%1").arg(id)));
        bmList.append( bm );
    }
}

void Settings::addBookmark(Bookmark *bm)
{
    bmList.append(bm);
}

void Settings::setView(int v)
{
    View = v;
}

void Settings::setSlideDelay( int d )
{
    delay = d;
}

void Settings::setRotateInSlide( bool r )
{
    rotate = r;
}

void Settings::setControlBarInSlide( bool s )
{
    controlBar = s;
}

void Settings::setShowImageFullScreen(bool b)
{
    fullScreen = b;
}

void Settings::setRotateBestFit(bool r)
{
    rotateFit = r;
}

void Settings::setSaveThumbnail(bool s)
{
    thumbnail = s;
}

void Settings::setThumbFileSize( int size )
{
    tFileSize = size;
}

void Settings::setShowFileExtension(bool b)
{
    ext =b;
}

void Settings::setShowImageDimension( bool b )
{
    imgDimension = b;
}

int Settings::view()
{
    return View;
}

int Settings::slideDelay()
{
    return delay;
}

bool Settings::rotateInSlide()
{
    return rotate;
}

bool Settings::showImageFullScreen()
{
    return fullScreen;
}

bool Settings::rotateBestFit()
{
    return rotateFit;
}

bool Settings::controlBarInSlide()
{
    return controlBar;
}

bool Settings::saveThumbnail()
{
    return thumbnail;
}

int Settings::thumbFileSize()
{
    return tFileSize;
}

bool Settings::showFileExtension()
{
    return ext;
}

bool Settings::showImageDimension()
{
    return imgDimension;
}

QList<Bookmark> *Settings::bookmarks()
{
    return &bmList;
}
