/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/


#include <qpe/resource.h>
#include <qcheckbox.h>
#include <qbuttongroup.h>
#include <qlistview.h>
#include <qlineedit.h>
#include <qslider.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qspinbox.h>

#include "settings.h"
#include "bookmark.h"
#include "settingsdialog.h"


SettingsDialog::SettingsDialog(QWidget *parent = 0, const char *name = 0)
              : SettingsDialogBase(parent, name, true)
{
    settings = NULL;
    newB->setPixmap(Resource::loadPixmap("new"));
    deleteB->setPixmap(Resource::loadPixmap("editdelete"));
}

void SettingsDialog::initSettings( Settings *s )
{
    settings = s;
    init();
}

void SettingsDialog::init()
{
    dimensionCheck->setChecked( settings->showImageDimension() );
    extCheck->setChecked( settings->showFileExtension() );
    thumbCheck->setChecked( settings->saveThumbnail() );
    thumbSize->setValue( settings->thumbFileSize() );
    delaySlider->setValue( settings->slideDelay() );
    delayChanged( settings->slideDelay() );
    rotateCheck->setChecked( settings->rotateInSlide() );
    barCheck->setChecked( settings->controlBarInSlide() );
    QListIterator<Bookmark> it(*settings->bookmarks());
    for( ; it.current(); ++it )
    {
        Bookmark *bm = (Bookmark *)it.current();
        QListViewItem *item = new QListViewItem(bmListView, bm->name(), bm->directory() );
        bmListView->insertItem(item);
    }
    if(bmListView->childCount())
        deleteB->setEnabled(TRUE);
}

int SettingsDialog::exec()
{
    showMaximized();
    return SettingsDialogBase::exec();
}

void SettingsDialog::saveSettings()
{
    settings->setSaveThumbnail( thumbCheck->isChecked() );
    settings->setThumbFileSize( thumbSize->value() );
    settings->setSlideDelay( delaySlider->value() );
    settings->setRotateInSlide( rotateCheck->isChecked() );
    settings->setControlBarInSlide( barCheck->isChecked() );
    settings->setShowFileExtension( extCheck->isChecked() );
    settings->setShowImageDimension( dimensionCheck->isChecked() );

    //save new bookmarks
    QListViewItemIterator it(bmListView);
    settings->bookmarks()->clear();
    for( ; it.current(); ++it)
    {
        QListViewItem *item = (QListViewItem *)it.current();
        Bookmark *bm = new Bookmark;
        if( !item->text(0).isEmpty() && !item->text(1).isEmpty() )
        {
            bm->setName( item->text(0) );
            bm->setDirectory( item->text(1) );
            settings->addBookmark(bm);
        }

    }
}

void SettingsDialog::saveThumbnailsChecked(bool on)
{
    thumbLabel->setEnabled(on);
    thumbSize->setEnabled(on);
}

void SettingsDialog::delayChanged(int delay)
{
    delayLabel->setText( QString::number( delay ) + " s" );
}

void SettingsDialog::newBookmark()
{
    QListViewItem *item = new QListViewItem(bmListView, "New Bookmark", "/mnt/cf");
    bmListView->insertItem(item);
    bmListView->setSelected(item, TRUE);
    editFrame->setEnabled( TRUE );
    deleteB->setEnabled(TRUE);
}

void SettingsDialog::deleteBookmark()
{
    QListViewItem *item = bmListView->selectedItem();
    if(!item)
        return;
    bmListView->removeItem(item);
    nameEdit->clear();
    dirEdit->clear();
    if(!bmListView->childCount())
        editFrame->setEnabled( FALSE );
}

void SettingsDialog::selectionChanged(QListViewItem *item)
{
    nameEdit->setText( item->text(0) );
    dirEdit->setText( item->text(1) );
    editFrame->setEnabled(TRUE);
}

void SettingsDialog::bmNameChanged(const QString &str)
{
    QListViewItem *item = bmListView->selectedItem();
    if(!item)
        return;
    item->setText(0, str);
}

void SettingsDialog::bmDirChanged(const QString &str)
{
    QListViewItem *item = bmListView->selectedItem();
    if(!item)
        return;
    item->setText(1, str);
}

