/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/


#ifndef _THUMBNAIL_VIEW_
#define _THUMBNAIL_VIEW_

#include <qwidget.h>
#include <qscrollview.h>
#include <qlist.h>

class DocLnk;
class QScrollView;
class QGridLayout;
class ImageViewer;
class Settings;
class ImageListViewItem;
class QPixmap;


class ImageBox : public QWidget
{
    Q_OBJECT
public:
    ImageBox( QWidget *parent, Settings *s, ImageListViewItem *d, const char *name=0 );
    ~ImageBox();
    DocLnk *docLnk();
    void setSelected(bool sel);
    bool isSelected();

    signals:
    void clicked();
    void upPressed();
    void downPressed();
    void leftPressed();
    void rightPressed();

public slots:
    void loadThumb();

protected:
    void paintEvent( QPaintEvent * );
    void keyPressEvent( QKeyEvent *e );
    void mouseReleaseEvent(QMouseEvent* event);

private:
    DocLnk *doc;
    ImageListViewItem *item; //listviewitem of this image
    QPixmap *scaledPixmap; //thumbnail pixmap
    int imgWidth, imgHeight;  //image info
    bool thumbLoaded, selected;
    QString fileName;
    Settings *settings;
};


class ThumbnailView : public QScrollView
{
    Q_OBJECT
public:
    ThumbnailView(QWidget *parent, Settings *s, const char *name=0);
    ~ThumbnailView();
    void addImage(ImageListViewItem *item, int row, int col);
    void selectImage(int pos);
    void setFocus();
    QScrollView *scrollView(){return scroll;}
    ImageBox *find(DocLnk *d);
    ImageBox *selectedImage();
    void clear(bool del=FALSE);
    void deleteImage(ImageBox *box);
    void deleteImage(DocLnk *d);

    signals:
    void imageClicked(DocLnk *);

public slots:
    void loadThumbs();

private slots:
    void boxClicked();
    void rightPressed();
    void leftPressed();
    void upPressed();
    void downPressed();

private:
    QList<ImageBox> boxList;
    QWidget *container;
    QScrollView *scroll;
    QGridLayout *gridLayout;
    ImageViewer *imageViewer;
    Settings *settings;
};

#endif
