/***********************************************************************
** TxImage - Image Viewer
** Copyright (C) 2003
** Pierpaolo Di Panfilo <pippo_dp@libero.it>
** Cristian Di Panfilo <cridipan@virgilio.it>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.  To obtain a
** copy of the GNU Library General Public License, write to the Free
** Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
** Any permitted reproduction of these routines, in whole or in part,
** must bear this legend.
**
*************************************************************************/


#ifndef _TXIMAGE_H
#define _TXIMAGE_H

#include <qmainwindow.h>
#include <qlist.h>
#include <qlistview.h>

class ImageViewer;
class QPEToolBar;
class QPopupMenu;
class QWidgetStack;
class ImageListView;
class QToolButton;
class BookmarkMenu;
class Bookmark;
class ThumbnailView;
class DocLnk;
class Settings;

class TxImage : public QMainWindow
{
    Q_OBJECT
public:
    TxImage(QWidget *parent, const char *name=0, int f=0);
    ~TxImage();

public slots:
    void setDocument(const QString& appLnkFileName);
    void cardMessage(const QCString &, const QByteArray &);
    void showImage( DocLnk *d );

private slots:
    void load();
    void switchThumbnailView();
    void switchListView();
    void showBookmarkMenu();
    void setFullScreen();
    void showImageFullScreen();
    void bookmarkSelected(Bookmark &bm);
    void documentsSelected();
    void showSettingsDialog();
    void listItemClicked(QListViewItem *item);
    void renameImage();
    void deleteImage();
    void startSlideShow();

private:
    void init(QString path=0);
    int view(); //current view

    enum VIEWS {
        THUMBNAIL_VIEW=0,
        LIST_VIEW,
    };
    enum CHECK { FULLSCREEN };

    QPEToolBar *mToolbar;
    QList<DocLnk> docList; //used to pass the list of images to slideshow
    QToolButton *thumbViewB, *lView, *bookmarkB; //button in toolbar
    QWidgetStack *stack;
    ThumbnailView *thumbView;
    ImageListView *listView;
    QPopupMenu *settingsPopup;
    BookmarkMenu *bookmarkMenu;
    Bookmark *currentBookmark;
    Settings *settings;
    DocLnk *loadingImage; //used for delayed load
    bool fromDocument;  //loaded from document tab
    ImageViewer *imageViewer;
};

#endif
